Class: Aws::ResourceGroups::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ResourceGroups::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-resourcegroups/client.rb,
sig/client.rbs
Overview
An API client for ResourceGroups. To construct a client, you need to configure a :region and :credentials.
client = Aws::ResourceGroups::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateGroupResponseSuccess, _DeleteGroupResponseSuccess, _GetAccountSettingsResponseSuccess, _GetGroupConfigurationResponseSuccess, _GetGroupQueryResponseSuccess, _GetGroupResponseSuccess, _GetTagSyncTaskResponseSuccess, _GetTagsResponseSuccess, _GroupResourcesResponseSuccess, _ListGroupResourcesResponseSuccess, _ListGroupingStatusesResponseSuccess, _ListGroupsResponseSuccess, _ListTagSyncTasksResponseSuccess, _PutGroupConfigurationResponseSuccess, _SearchResourcesResponseSuccess, _StartTagSyncTaskResponseSuccess, _TagResponseSuccess, _UngroupResourcesResponseSuccess, _UntagResponseSuccess, _UpdateAccountSettingsResponseSuccess, _UpdateGroupQueryResponseSuccess, _UpdateGroupResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_tag_sync_task(params = {}) ⇒ Struct
Cancels the specified tag-sync task.
-
#create_group(params = {}) ⇒ Types::CreateGroupOutput
Creates a resource group with the specified name and description.
-
#delete_group(params = {}) ⇒ Types::DeleteGroupOutput
Deletes the specified resource group.
-
#get_account_settings(params = {}) ⇒ Types::GetAccountSettingsOutput
Retrieves the current status of optional features in Resource Groups.
-
#get_group(params = {}) ⇒ Types::GetGroupOutput
Returns information about a specified resource group.
-
#get_group_configuration(params = {}) ⇒ Types::GetGroupConfigurationOutput
Retrieves the service configuration associated with the specified resource group.
-
#get_group_query(params = {}) ⇒ Types::GetGroupQueryOutput
Retrieves the resource query associated with the specified resource group.
-
#get_tag_sync_task(params = {}) ⇒ Types::GetTagSyncTaskOutput
Returns information about a specified tag-sync task.
-
#get_tags(params = {}) ⇒ Types::GetTagsOutput
Returns a list of tags that are associated with a resource group, specified by an Amazon resource name (ARN).
-
#group_resources(params = {}) ⇒ Types::GroupResourcesOutput
Adds the specified resources to the specified group.
-
#list_group_resources(params = {}) ⇒ Types::ListGroupResourcesOutput
Returns a list of Amazon resource names (ARNs) of the resources that are members of a specified resource group.
-
#list_grouping_statuses(params = {}) ⇒ Types::ListGroupingStatusesOutput
Returns the status of the last grouping or ungrouping action for each resource in the specified application group.
-
#list_groups(params = {}) ⇒ Types::ListGroupsOutput
Returns a list of existing Resource Groups in your account.
-
#list_tag_sync_tasks(params = {}) ⇒ Types::ListTagSyncTasksOutput
Returns a list of tag-sync tasks.
-
#put_group_configuration(params = {}) ⇒ Struct
Attaches a service configuration to the specified group.
-
#search_resources(params = {}) ⇒ Types::SearchResourcesOutput
Returns a list of Amazon Web Services resource identifiers that matches the specified query.
-
#start_tag_sync_task(params = {}) ⇒ Types::StartTagSyncTaskOutput
Creates a new tag-sync task to onboard and sync resources tagged with a specific tag key-value pair to an application.
-
#tag(params = {}) ⇒ Types::TagOutput
Adds tags to a resource group with the specified Amazon resource name (ARN).
-
#ungroup_resources(params = {}) ⇒ Types::UngroupResourcesOutput
Removes the specified resources from the specified group.
-
#untag(params = {}) ⇒ Types::UntagOutput
Deletes tags from a specified resource group.
-
#update_account_settings(params = {}) ⇒ Types::UpdateAccountSettingsOutput
Turns on or turns off optional features in Resource Groups.
-
#update_group(params = {}) ⇒ Types::UpdateGroupOutput
Updates the description for an existing group.
-
#update_group_query(params = {}) ⇒ Types::UpdateGroupQueryOutput
Updates the resource query of a group.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-resourcegroups/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2037 2038 2039 |
# File 'lib/aws-sdk-resourcegroups/client.rb', line 2037 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2040 2041 2042 |
# File 'lib/aws-sdk-resourcegroups/client.rb', line 2040 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 |
# File 'lib/aws-sdk-resourcegroups/client.rb', line 2010 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ResourceGroups') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-resourcegroups' context[:gem_version] = '1.100.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_tag_sync_task(params = {}) ⇒ Struct
Cancels the specified tag-sync task.
Minimum permissions
To run this command, you must have the following permissions:
-
resource-groups:CancelTagSyncTaskon the application group -
resource-groups:DeleteGroup
82 |
# File 'sig/client.rbs', line 82
def cancel_tag_sync_task: (
|
#create_group(params = {}) ⇒ Types::CreateGroupOutput
Creates a resource group with the specified name and description. You can optionally include either a resource query or a service configuration. For more information about constructing a resource query, see Build queries and groups in Resource Groups in the Resource Groups User Guide. For more information about service-linked groups and service configurations, see Service configurations for Resource Groups.
Minimum permissions
To run this command, you must have the following permissions:
resource-groups:CreateGroup
^
95 |
# File 'sig/client.rbs', line 95
def create_group: (
|
#delete_group(params = {}) ⇒ Types::DeleteGroupOutput
Deletes the specified resource group. Deleting a resource group does not delete any resources that are members of the group; it only deletes the group structure.
Minimum permissions
To run this command, you must have the following permissions:
resource-groups:DeleteGroup
^
125 |
# File 'sig/client.rbs', line 125
def delete_group: (
|
#get_account_settings(params = {}) ⇒ Types::GetAccountSettingsOutput
Retrieves the current status of optional features in Resource Groups.
136 137 |
# File 'sig/client.rbs', line 136
def get_account_settings: () -> _GetAccountSettingsResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetAccountSettingsResponseSuccess
|
#get_group(params = {}) ⇒ Types::GetGroupOutput
Returns information about a specified resource group.
Minimum permissions
To run this command, you must have the following permissions:
resource-groups:GetGroup
^
144 |
# File 'sig/client.rbs', line 144
def get_group: (
|
#get_group_configuration(params = {}) ⇒ Types::GetGroupConfigurationOutput
Retrieves the service configuration associated with the specified resource group. For details about the service configuration syntax, see Service configurations for Resource Groups.
Minimum permissions
To run this command, you must have the following permissions:
resource-groups:GetGroupConfiguration
^
155 |
# File 'sig/client.rbs', line 155
def get_group_configuration: (
|
#get_group_query(params = {}) ⇒ Types::GetGroupQueryOutput
Retrieves the resource query associated with the specified resource group. For more information about resource queries, see Create a tag-based group in Resource Groups.
Minimum permissions
To run this command, you must have the following permissions:
resource-groups:GetGroupQuery
^
165 |
# File 'sig/client.rbs', line 165
def get_group_query: (
|
#get_tag_sync_task(params = {}) ⇒ Types::GetTagSyncTaskOutput
Returns information about a specified tag-sync task.
Minimum permissions
To run this command, you must have the following permissions:
resource-groups:GetTagSyncTaskon the application group
^
185 |
# File 'sig/client.rbs', line 185
def get_tag_sync_task: (
|
#get_tags(params = {}) ⇒ Types::GetTagsOutput
Returns a list of tags that are associated with a resource group, specified by an Amazon resource name (ARN).
Minimum permissions
To run this command, you must have the following permissions:
resource-groups:GetTags
^
196 |
# File 'sig/client.rbs', line 196
def get_tags: (
|
#group_resources(params = {}) ⇒ Types::GroupResourcesOutput
Adds the specified resources to the specified group.
You can only use this operation with the following groups:
-
AWS::EC2::HostManagement -
AWS::EC2::CapacityReservationPool -
AWS::ResourceGroups::ApplicationGroup
Other resource group types and resource types are not currently supported by this operation.
Minimum permissions
To run this command, you must have the following permissions:
resource-groups:GroupResources
^
208 |
# File 'sig/client.rbs', line 208
def group_resources: (
|
#list_group_resources(params = {}) ⇒ Types::ListGroupResourcesOutput
Returns a list of Amazon resource names (ARNs) of the resources that are members of a specified resource group.
Minimum permissions
To run this command, you must have the following permissions:
-
resource-groups:ListGroupResources -
cloudformation:DescribeStacks -
cloudformation:ListStackResources -
tag:GetResources
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
222 |
# File 'sig/client.rbs', line 222
def list_group_resources: (
|
#list_grouping_statuses(params = {}) ⇒ Types::ListGroupingStatusesOutput
Returns the status of the last grouping or ungrouping action for each resource in the specified application group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
243 |
# File 'sig/client.rbs', line 243
def list_grouping_statuses: (
|
#list_groups(params = {}) ⇒ Types::ListGroupsOutput
Returns a list of existing Resource Groups in your account.
Minimum permissions
To run this command, you must have the following permissions:
resource-groups:ListGroups
^
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
263 |
# File 'sig/client.rbs', line 263
def list_groups: (
|
#list_tag_sync_tasks(params = {}) ⇒ Types::ListTagSyncTasksOutput
Returns a list of tag-sync tasks.
Minimum permissions
To run this command, you must have the following permissions:
resource-groups:ListTagSyncTaskswith the group passed in the filters as the resource or * if using no filters
^
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
281 |
# File 'sig/client.rbs', line 281
def list_tag_sync_tasks: (
|
#put_group_configuration(params = {}) ⇒ Struct
Attaches a service configuration to the specified group. This occurs asynchronously, and can take time to complete. You can use GetGroupConfiguration to check the status of the update.
Minimum permissions
To run this command, you must have the following permissions:
resource-groups:PutGroupConfiguration
^
297 |
# File 'sig/client.rbs', line 297
def put_group_configuration: (
|
#search_resources(params = {}) ⇒ Types::SearchResourcesOutput
Returns a list of Amazon Web Services resource identifiers that matches the specified query. The query uses the same format as a resource query in a CreateGroup or UpdateGroupQuery operation.
Minimum permissions
To run this command, you must have the following permissions:
-
resource-groups:SearchResources -
cloudformation:DescribeStacks -
cloudformation:ListStackResources -
tag:GetResources
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
320 |
# File 'sig/client.rbs', line 320
def search_resources: (
|
#start_tag_sync_task(params = {}) ⇒ Types::StartTagSyncTaskOutput
Creates a new tag-sync task to onboard and sync resources tagged with a specific tag key-value pair to an application. To start a tag-sync task, you need a resource tagging role. The resource tagging role grants permissions to tag and untag applications resources and must include a trust policy that allows Resource Groups to assume the role and perform resource tagging tasks on your behalf.
For instructions on creating a tag-sync task, see Create a tag-sync using the Resource Groups API in the Amazon Web Services Service Catalog AppRegistry Administrator Guide.
Minimum permissions
To run this command, you must have the following permissions:
-
resource-groups:StartTagSyncTaskon the application group -
resource-groups:CreateGroup -
iam:PassRoleon the role provided in the request
341 |
# File 'sig/client.rbs', line 341
def start_tag_sync_task: (
|
#tag(params = {}) ⇒ Types::TagOutput
Adds tags to a resource group with the specified Amazon resource name (ARN). Existing tags on a resource group are not changed if they are not specified in the request parameters.
Do not store personally identifiable information (PII) or other confidential or sensitive information in tags. We use tags to provide you with billing and administration services. Tags are not intended to be used for private or sensitive data.
Minimum permissions
To run this command, you must have the following permissions:
resource-groups:Tag
^
359 |
# File 'sig/client.rbs', line 359
def tag: (
|
#ungroup_resources(params = {}) ⇒ Types::UngroupResourcesOutput
Removes the specified resources from the specified group. This operation works only with static groups that you populated using the GroupResources operation. It doesn't work with any resource groups that are automatically populated by tag-based or CloudFormation stack-based queries.
Minimum permissions
To run this command, you must have the following permissions:
resource-groups:UngroupResources
^
372 |
# File 'sig/client.rbs', line 372
def ungroup_resources: (
|
#untag(params = {}) ⇒ Types::UntagOutput
Deletes tags from a specified resource group.
Minimum permissions
To run this command, you must have the following permissions:
resource-groups:Untag
^
384 |
# File 'sig/client.rbs', line 384
def untag: (
|
#update_account_settings(params = {}) ⇒ Types::UpdateAccountSettingsOutput
Turns on or turns off optional features in Resource Groups.
The preceding example shows that the request to turn on group
lifecycle events is IN_PROGRESS. You can call the GetAccountSettings
operation to check for completion by looking for
GroupLifecycleEventsStatus to change to ACTIVE.
395 |
# File 'sig/client.rbs', line 395
def update_account_settings: (
|
#update_group(params = {}) ⇒ Types::UpdateGroupOutput
Updates the description for an existing group. You cannot update the name of a resource group.
Minimum permissions
To run this command, you must have the following permissions:
resource-groups:UpdateGroup
^
405 |
# File 'sig/client.rbs', line 405
def update_group: (
|
#update_group_query(params = {}) ⇒ Types::UpdateGroupQueryOutput
Updates the resource query of a group. For more information about resource queries, see Create a tag-based group in Resource Groups.
Minimum permissions
To run this command, you must have the following permissions:
resource-groups:UpdateGroupQuery
^
420 |
# File 'sig/client.rbs', line 420
def update_group_query: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2030 2031 2032 |
# File 'lib/aws-sdk-resourcegroups/client.rb', line 2030 def waiter_names [] end |