Class: Aws::ResourceGroups::Types::ListGroupResourcesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::ResourceGroups::Types::ListGroupResourcesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resourcegroups/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::ResourceFilter>
Filters, formatted as ResourceFilter objects, that you want to apply to a
ListGroupResourcesoperation. -
#group ⇒ String
The name or the Amazon resource name (ARN) of the resource group.
-
#group_name ⇒ String
Deprecated - don't use this parameter.
-
#max_results ⇒ Integer
The total number of results that you want included on each page of the response.
-
#next_token ⇒ String
The parameter for receiving additional results if you receive a
NextTokenresponse in a previous request.
Instance Attribute Details
#filters ⇒ Array<Types::ResourceFilter>
Filters, formatted as ResourceFilter objects, that you want to apply
to a ListGroupResources operation. Filters the results to include
only those of the specified resource types.
resource-type- Filter resources by their type. Specify up to five resource types in the formatAWS::ServiceCode::ResourceType. For example,AWS::EC2::Instance, orAWS::S3::Bucket.
^
When you specify a resource-type filter for ListGroupResources,
Resource Groups validates your filter resource types against the
types that are defined in the query associated with the group. For
example, if a group contains only S3 buckets because its query
specifies only that resource type, but your resource-type filter
includes EC2 instances, AWS Resource Groups does not filter for EC2
instances. In this case, a ListGroupResources request returns a
BadRequestException error with a message similar to the following:
The resource types specified as filters in the request are not valid.
The error includes a list of resource types that failed the
validation because they are not part of the query associated with
the group. This validation doesn't occur when the group query
specifies AWS::AllSupported, because a group based on such a query
can contain any of the allowed resource types for the query type
(tag-based or Amazon CloudFront stack-based queries).
950 951 952 953 954 955 956 957 958 |
# File 'lib/aws-sdk-resourcegroups/types.rb', line 950 class ListGroupResourcesInput < Struct.new( :group_name, :group, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#group ⇒ String
The name or the Amazon resource name (ARN) of the resource group.
950 951 952 953 954 955 956 957 958 |
# File 'lib/aws-sdk-resourcegroups/types.rb', line 950 class ListGroupResourcesInput < Struct.new( :group_name, :group, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
Deprecated - don't use this parameter. Use the
Group request field instead.
950 951 952 953 954 955 956 957 958 |
# File 'lib/aws-sdk-resourcegroups/types.rb', line 950 class ListGroupResourcesInput < Struct.new( :group_name, :group, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The total number of results that you want included on each page of
the response. If you do not include this parameter, it defaults to a
value that is specific to the operation. If additional items exist
beyond the maximum you specify, the NextToken response element is
present and has a value (is not null). Include that value as the
NextToken request parameter in the next call to the operation to
get the next part of the results. Note that the service might return
fewer results than the maximum even when there are more results
available. You should check NextToken after every operation to
ensure that you receive all of the results.
950 951 952 953 954 955 956 957 958 |
# File 'lib/aws-sdk-resourcegroups/types.rb', line 950 class ListGroupResourcesInput < Struct.new( :group_name, :group, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The parameter for receiving additional results if you receive a
NextToken response in a previous request. A NextToken response
indicates that more output is available. Set this parameter to the
value provided by a previous call's NextToken response to
indicate where the output should continue from.
950 951 952 953 954 955 956 957 958 |
# File 'lib/aws-sdk-resourcegroups/types.rb', line 950 class ListGroupResourcesInput < Struct.new( :group_name, :group, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |