Class: Aws::ResourceGroups::Types::ListGroupingStatusesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::ResourceGroups::Types::ListGroupingStatusesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resourcegroups/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group ⇒ String
The application group identifier, expressed as an Amazon resource name (ARN) or the application group name.
-
#grouping_statuses ⇒ Array<Types::GroupingStatusesItem>
Returns details about the grouping or ungrouping status of the resources in the specified application group.
-
#next_token ⇒ String
If present, indicates that more output is available than is included in the current response.
Instance Attribute Details
#group ⇒ String
The application group identifier, expressed as an Amazon resource name (ARN) or the application group name.
1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/aws-sdk-resourcegroups/types.rb', line 1101 class ListGroupingStatusesOutput < Struct.new( :group, :grouping_statuses, :next_token) SENSITIVE = [] include Aws::Structure end |
#grouping_statuses ⇒ Array<Types::GroupingStatusesItem>
Returns details about the grouping or ungrouping status of the resources in the specified application group.
1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/aws-sdk-resourcegroups/types.rb', line 1101 class ListGroupingStatusesOutput < Struct.new( :group, :grouping_statuses, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If present, indicates that more output is available than is included
in the current response. Use this value in the NextToken request
parameter in a subsequent call to the operation to get the next part
of the output. You should repeat this until the NextToken response
element comes back as null.
1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/aws-sdk-resourcegroups/types.rb', line 1101 class ListGroupingStatusesOutput < Struct.new( :group, :grouping_statuses, :next_token) SENSITIVE = [] include Aws::Structure end |