Class: Aws::ResourceGroups::Types::ListGroupsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::ResourceGroups::Types::ListGroupsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resourcegroups/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group_identifiers ⇒ Array<Types::GroupIdentifier>
A list of GroupIdentifier objects.
-
#groups ⇒ Array<Types::Group>
Deprecated - don't use this field.
-
#next_token ⇒ String
If present, indicates that more output is available than is included in the current response.
Instance Attribute Details
#group_identifiers ⇒ Array<Types::GroupIdentifier>
A list of GroupIdentifier objects. Each identifier is an object that
contains both the Name and the GroupArn.
1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-resourcegroups/types.rb', line 1189 class ListGroupsOutput < Struct.new( :group_identifiers, :groups, :next_token) SENSITIVE = [] include Aws::Structure end |
#groups ⇒ Array<Types::Group>
Deprecated - don't use this field. Use the
GroupIdentifiers response field instead.
1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-resourcegroups/types.rb', line 1189 class ListGroupsOutput < Struct.new( :group_identifiers, :groups, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If present, indicates that more output is available than is included
in the current response. Use this value in the NextToken request
parameter in a subsequent call to the operation to get the next part
of the output. You should repeat this until the NextToken response
element comes back as null.
1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-resourcegroups/types.rb', line 1189 class ListGroupsOutput < Struct.new( :group_identifiers, :groups, :next_token) SENSITIVE = [] include Aws::Structure end |